[![PyPI](https://img.shields.io/pypi/v/paxplot)](https://pypi.org/project/paxplot/)
[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/kravitsjacob/paxplot/Version%20Testing)](https://github.com/kravitsjacob/paxplot/actions)
[![GitHub license](https://img.shields.io/github/license/kravitsjacob/paxplot)](https://github.com/kravitsjacob/paxplot/blob/main/LICENSE)

# Paxplot
Paxplot is a Python visualization library for parallel coordinate plots based on matplotlib.

Check out our [homepage](https://kravitsjacob.github.io/paxplot/) for more information.

# Installation
The latest stable release (and required dependencies) can be installed from PyPI:

```
pip install paxplot
```

For addition installation instructions, see the [Getting Started](https://kravitsjacob.github.io/paxplot/getting_started.html) documentation.

# Reporting Bugs
Please report all bugs using [issues](https://github.com/kravitsjacob/paxplot/issues).

# Contributing
Paxplot welcomes contributions! Users familiar with matplotlib should have no problem using/contributing to this project.

1. We recommend conda to manage environments and ensure consistent results. Download [miniconda](https://docs.conda.io/en/latest/miniconda.html) and ensure you can activate it from your terminal by running `$ conda activate` 
    * Depending on system configuration, this can be an involved process. [Here](https://discuss.codecademy.com/t/setting-up-conda-in-git-bash/534473) is a recommended thread.
3. Clone the repository using `$ git clone https://github.com/kravitsjacob/paxplot.git` 
4. Change to the current working directory using `$ cd paxplot`
5. Install the development environment `$ conda env create -f environment.yml`
6. Activate the environmet and you are ready to contribute!
